@@ -5,12 +5,12 @@ import (
 	"reflect"
 	"strings"
 
-	v1 "k8s.io/api/core/v1"
+	"k8s.io/apimachinery/pkg/api/equality"
 
 	"github.com/golang/glog"
-
 	osconfigv1 "github.com/openshift/api/config/v1"
 	cvoresourcemerge "github.com/openshift/cluster-version-operator/lib/resourcemerge"
+	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
@@ -30,6 +30,15 @@ const (
 	clusterOperatorName = "machine-api"
 )
 
+var (
+	// This is to be compliant with
+	// https://github.com/openshift/cluster-version-operator/blob/b57ee63baf65f7cb6e95a8b2b304d88629cfe3c0/docs/dev/clusteroperator.md#what-should-an-operator-report-with-clusteroperator-custom-resource
+	// When known hazardous states for upgrades are determined
+	// specific "Upgradeable=False" status can be added with messages for how admins
+	// can resolve it.
+	operatorUpgradeable = newClusterOperatorStatusCondition(osconfigv1.OperatorUpgradeable, osconfigv1.ConditionTrue, "", "")
+)
+
 // statusProgressing sets the Progressing condition to True, with the given
 // reason and message, and sets both the Available and Degraded conditions to
 // False.
@@ -64,6 +73,7 @@ func (optr *Operator) statusProgressing() error {
 		newClusterOperatorStatusCondition(osconfigv1.OperatorProgressing, isProgressing, string(ReasonSyncing), message),
 		newClusterOperatorStatusCondition(osconfigv1.OperatorAvailable, osconfigv1.ConditionTrue, "", ""),
 		newClusterOperatorStatusCondition(osconfigv1.OperatorDegraded, osconfigv1.ConditionFalse, "", ""),
+		operatorUpgradeable,
 	}
 
 	return optr.syncStatus(co, conds)
@@ -77,6 +87,7 @@ func (optr *Operator) statusAvailable() error {
 			fmt.Sprintf("Cluster Machine API Operator is available at %s", optr.printOperandVersions())),
 		newClusterOperatorStatusCondition(osconfigv1.OperatorProgressing, osconfigv1.ConditionFalse, "", ""),
 		newClusterOperatorStatusCondition(osconfigv1.OperatorDegraded, osconfigv1.ConditionFalse, "", ""),
+		operatorUpgradeable,
 	}
 
 	co, err := optr.getOrCreateClusterOperator()
@@ -114,6 +125,7 @@ func (optr *Operator) statusDegraded(error string) error {
 			string(ReasonSyncFailed), message),
 		newClusterOperatorStatusCondition(osconfigv1.OperatorProgressing, osconfigv1.ConditionFalse, "", ""),
 		newClusterOperatorStatusCondition(osconfigv1.OperatorAvailable, osconfigv1.ConditionTrue, "", ""),
+		operatorUpgradeable,
 	}
 
 	co, err := optr.getOrCreateClusterOperator()
@@ -148,36 +160,63 @@ func (optr *Operator) syncStatus(co *osconfigv1.ClusterOperator, conds []osconfi
 }
 
 func (optr *Operator) getOrCreateClusterOperator() (*osconfigv1.ClusterOperator, error) {
+	var co *osconfigv1.ClusterOperator
 	co, err := optr.osClient.ConfigV1().ClusterOperators().Get(clusterOperatorName, metav1.GetOptions{})
 	if errors.IsNotFound(err) {
-		// to report the status of all the managed components.
-		// TODO we will report the version of the operands (so our machine api implementation version)
-		// NOTE: related objects lets openshift/must-gather collect diagnostic content
 		co = &osconfigv1.ClusterOperator{
 			ObjectMeta: metav1.ObjectMeta{
 				Name: clusterOperatorName,
 			},
-			Status: osconfigv1.ClusterOperatorStatus{
-				Versions: optr.operandVersions,
-				RelatedObjects: []osconfigv1.ObjectReference{
-					{
-						Group:    "",
-						Resource: "namespaces",
-						Name:     optr.namespace,
-					},
-				},
-			},
 		}
-
-		glog.Infof("%s clusterOperator status does not exist, creating %v", clusterOperatorName, co)
-		co, err := optr.osClient.ConfigV1().ClusterOperators().Create(co)
+		glog.Infof("clusterOperator %q does not exist, creating a new one: %v", clusterOperatorName, co)
+		co, err = optr.osClient.ConfigV1().ClusterOperators().Create(co)
 		if err != nil {
-			return nil, err
+			return nil, fmt.Errorf("failed to create new clusterOperator: %v", err)
 		}
-		return co, nil
 	}
 	if err != nil {
-		return nil, err
+		return nil, fmt.Errorf("failed to get clusterOperator %q: %v", clusterOperatorName, err)
+	}
+
+	// Related objects lets openshift/must-gather collect diagnostic content
+	relatedObjects := []osconfigv1.ObjectReference{
+		{
+			Group:    "",
+			Resource: "namespaces",
+			Name:     optr.namespace,
+		},
+		{
+			Group:     "machine.openshift.io",
+			Resource:  "machines",
+			Name:      "",
+			Namespace: optr.namespace,
+		},
+		{
+			Group:     "machine.openshift.io",
+			Resource:  "machinesets",
+			Name:      "",
+			Namespace: optr.namespace,
+		},
+		{
+			Group:     "rbac.authorization.k8s.io",
+			Resource:  "roles",
+			Name:      "",
+			Namespace: optr.namespace,
+		},
+		{
+			Group:    "rbac.authorization.k8s.io",
+			Resource: "clusterroles",
+			Name:     "machine-api-operator",
+		},
+		{
+			Group:    "rbac.authorization.k8s.io",
+			Resource: "clusterroles",
+			Name:     "machine-api-controllers",
+		},
+	}
+	if !equality.Semantic.DeepEqual(co.Status.RelatedObjects, relatedObjects) {
+		co.Status.RelatedObjects = relatedObjects
+		return optr.osClient.ConfigV1().ClusterOperators().UpdateStatus(co)
 	}
 	return co, nil
 }
