@@ -177,6 +177,22 @@ func TestGetOrCreateClusterOperator(t *testing.T) {
 							Name:      "",
 							Namespace: namespace,
 						},
+						{
+							Group:     "rbac.authorization.k8s.io",
+							Resource:  "roles",
+							Name:      "",
+							Namespace: namespace,
+						},
+						{
+							Group:    "rbac.authorization.k8s.io",
+							Resource: "clusterroles",
+							Name:     "machine-api-operator",
+						},
+						{
+							Group:    "rbac.authorization.k8s.io",
+							Resource: "clusterroles",
+							Name:     "machine-api-controllers",
+						},
 					},
 				},
 			},
@@ -213,6 +229,22 @@ func TestGetOrCreateClusterOperator(t *testing.T) {
 							Name:      "",
 							Namespace: namespace,
 						},
+						{
+							Group:     "rbac.authorization.k8s.io",
+							Resource:  "roles",
+							Name:      "",
+							Namespace: namespace,
+						},
+						{
+							Group:    "rbac.authorization.k8s.io",
+							Resource: "clusterroles",
+							Name:     "machine-api-operator",
+						},
+						{
+							Group:    "rbac.authorization.k8s.io",
+							Resource: "clusterroles",
+							Name:     "machine-api-controllers",
+						},
 					},
 					Conditions: conditions,
 				},
